# Autogenerated by nbdev

d = { 'settings': { 'branch': 'master',
                'doc_baseurl': '/lovely-tensors',
                'doc_host': 'https://xl0.github.io',
                'git_url': 'https://github.com/xl0/lovely-tensors',
                'lib_path': 'lovely_tensors'},
  'syms': { 'lovely_tensors.patch': {'lovely_tensors.patch.monkey_patch': ('patch.html#monkey_patch', 'lovely_tensors/patch.py')},
            'lovely_tensors.repr_chans': { 'lovely_tensors.repr_chans.ChanProxy': ( 'repr_chans.html#chanproxy',
                                                                                    'lovely_tensors/repr_chans.py'),
                                           'lovely_tensors.repr_chans.ChanProxy.__call__': ( 'repr_chans.html#chanproxy.__call__',
                                                                                             'lovely_tensors/repr_chans.py'),
                                           'lovely_tensors.repr_chans.ChanProxy.__init__': ( 'repr_chans.html#chanproxy.__init__',
                                                                                             'lovely_tensors/repr_chans.py'),
                                           'lovely_tensors.repr_chans.ChanProxy._repr_png_': ( 'repr_chans.html#chanproxy._repr_png_',
                                                                                               'lovely_tensors/repr_chans.py'),
                                           'lovely_tensors.repr_chans.ChanProxy.fig': ( 'repr_chans.html#chanproxy.fig',
                                                                                        'lovely_tensors/repr_chans.py'),
                                           'lovely_tensors.repr_chans.chans': ('repr_chans.html#chans', 'lovely_tensors/repr_chans.py')},
            'lovely_tensors.repr_plt': { 'lovely_tensors.repr_plt.PlotProxy': ('repr_plt.html#plotproxy', 'lovely_tensors/repr_plt.py'),
                                         'lovely_tensors.repr_plt.PlotProxy.__call__': ( 'repr_plt.html#plotproxy.__call__',
                                                                                         'lovely_tensors/repr_plt.py'),
                                         'lovely_tensors.repr_plt.PlotProxy.__init__': ( 'repr_plt.html#plotproxy.__init__',
                                                                                         'lovely_tensors/repr_plt.py'),
                                         'lovely_tensors.repr_plt.PlotProxy._repr_png_': ( 'repr_plt.html#plotproxy._repr_png_',
                                                                                           'lovely_tensors/repr_plt.py'),
                                         'lovely_tensors.repr_plt.PlotProxy._repr_svg_': ( 'repr_plt.html#plotproxy._repr_svg_',
                                                                                           'lovely_tensors/repr_plt.py'),
                                         'lovely_tensors.repr_plt.PlotProxy.fig': ( 'repr_plt.html#plotproxy.fig',
                                                                                    'lovely_tensors/repr_plt.py'),
                                         'lovely_tensors.repr_plt.plot': ('repr_plt.html#plot', 'lovely_tensors/repr_plt.py')},
            'lovely_tensors.repr_rgb': { 'lovely_tensors.repr_rgb.RGBProxy': ('repr_rgb.html#rgbproxy', 'lovely_tensors/repr_rgb.py'),
                                         'lovely_tensors.repr_rgb.RGBProxy.__call__': ( 'repr_rgb.html#rgbproxy.__call__',
                                                                                        'lovely_tensors/repr_rgb.py'),
                                         'lovely_tensors.repr_rgb.RGBProxy.__init__': ( 'repr_rgb.html#rgbproxy.__init__',
                                                                                        'lovely_tensors/repr_rgb.py'),
                                         'lovely_tensors.repr_rgb.RGBProxy._repr_png_': ( 'repr_rgb.html#rgbproxy._repr_png_',
                                                                                          'lovely_tensors/repr_rgb.py'),
                                         'lovely_tensors.repr_rgb.RGBProxy.fig': ( 'repr_rgb.html#rgbproxy.fig',
                                                                                   'lovely_tensors/repr_rgb.py'),
                                         'lovely_tensors.repr_rgb.rgb': ('repr_rgb.html#rgb', 'lovely_tensors/repr_rgb.py')},
            'lovely_tensors.repr_str': { 'lovely_tensors.repr_str.StrProxy': ('repr_str.html#strproxy', 'lovely_tensors/repr_str.py'),
                                         'lovely_tensors.repr_str.StrProxy.__call__': ( 'repr_str.html#strproxy.__call__',
                                                                                        'lovely_tensors/repr_str.py'),
                                         'lovely_tensors.repr_str.StrProxy.__init__': ( 'repr_str.html#strproxy.__init__',
                                                                                        'lovely_tensors/repr_str.py'),
                                         'lovely_tensors.repr_str.StrProxy.__repr__': ( 'repr_str.html#strproxy.__repr__',
                                                                                        'lovely_tensors/repr_str.py'),
                                         'lovely_tensors.repr_str.history_warning': ( 'repr_str.html#history_warning',
                                                                                      'lovely_tensors/repr_str.py'),
                                         'lovely_tensors.repr_str.is_cpu': ('repr_str.html#is_cpu', 'lovely_tensors/repr_str.py'),
                                         'lovely_tensors.repr_str.is_nasty': ('repr_str.html#is_nasty', 'lovely_tensors/repr_str.py'),
                                         'lovely_tensors.repr_str.lovely': ('repr_str.html#lovely', 'lovely_tensors/repr_str.py'),
                                         'lovely_tensors.repr_str.plain_repr': ('repr_str.html#plain_repr', 'lovely_tensors/repr_str.py'),
                                         'lovely_tensors.repr_str.plain_str': ('repr_str.html#plain_str', 'lovely_tensors/repr_str.py'),
                                         'lovely_tensors.repr_str.short_dtype': ('repr_str.html#short_dtype', 'lovely_tensors/repr_str.py'),
                                         'lovely_tensors.repr_str.to_str': ('repr_str.html#to_str', 'lovely_tensors/repr_str.py'),
                                         'lovely_tensors.repr_str.torch_to_str_common': ( 'repr_str.html#torch_to_str_common',
                                                                                          'lovely_tensors/repr_str.py'),
                                         'lovely_tensors.repr_str.type_to_dtype': ( 'repr_str.html#type_to_dtype',
                                                                                    'lovely_tensors/repr_str.py')},
            'lovely_tensors.utils.config': { 'lovely_tensors.utils.config.Config': ( 'utils.config.html#config',
                                                                                     'lovely_tensors/utils/config.py'),
                                             'lovely_tensors.utils.config.Config.__init__': ( 'utils.config.html#config.__init__',
                                                                                              'lovely_tensors/utils/config.py'),
                                             'lovely_tensors.utils.config._Default': ( 'utils.config.html#_default',
                                                                                       'lovely_tensors/utils/config.py'),
                                             'lovely_tensors.utils.config._Default.__repr__': ( 'utils.config.html#_default.__repr__',
                                                                                                'lovely_tensors/utils/config.py'),
                                             'lovely_tensors.utils.config.config': ( 'utils.config.html#config',
                                                                                     'lovely_tensors/utils/config.py'),
                                             'lovely_tensors.utils.config.get_config': ( 'utils.config.html#get_config',
                                                                                         'lovely_tensors/utils/config.py'),
                                             'lovely_tensors.utils.config.set_config': ( 'utils.config.html#set_config',
                                                                                         'lovely_tensors/utils/config.py')},
            'lovely_tensors.utils.misc': { 'lovely_tensors.utils.misc.to_numpy': ( 'utils.misc.html#to_numpy',
                                                                                   'lovely_tensors/utils/misc.py')}}}
